#
# spec file for package gopls
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gopls
Version:        0.13.2
Release:        2.1
Summary:        Go LSP protocol language server
License:        Apache-2.0 AND MIT AND BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://pkg.go.dev/golang.org/x/tools/gopls
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.18

%description
gopls (pronounced "Go please") is the official Go language server developed
by the Go team. It provides IDE features to any LSP-compatible editor.

%prep
%autosetup -a 1
# Upstream Go x/tools monorepo has a subdir per tool.
# Unlike most Go applications at the repository root,
# package x/tools sources as subdir/ so we can include
# LICENSE file from monorepo top level dir.
mv LICENSE %{name}
# vendor dir must also be moved to subdir to be detected
mv vendor %{name}

%build
# Change to subdir, see comment in prep phase
cd %{name}
go build \
   -mod=vendor \
   -buildmode=pie \

%check
# Account for subdir, see comment in prep phase
# Execute the binary as a basic check
./%{name}/%{name} --help

%install
# Account for subdir, see comment in prep phase
install -D -m 0755 %{name}/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
# Account for subdir, see comment in prep phase
%doc %{name}/README.md
%license %{name}/LICENSE
%{_bindir}/%{name}

%changelog
* Tue Sep 12 2023 Lubos Kocman <lubos.kocman@suse.com>
- License correction based on legaldb review
  Add Apache-2.0 and MIT for vendor/gopkg.in/yaml.v3
* Thu Aug 17 2023 jkowalczyk@suse.com
- Update to version 0.13.2:
  * gopls: update go.mod for v0.13.2-pre.1
  * [gopls-release-branch.0.13] refactor/satisfy: (re)allow composite lits of pointer type
* Sat Aug 12 2023 jkowalczyk@suse.com
- Update to version 0.13.1:
  * gopls: update go.mod for v0.13.1-pre.2
  * gopls/internal/hooks: clean language version before passing to gofumpt
  * gopls/internal/lsp/analysis: fix stubmethods with variadic parameters
  * gopls: update go.mod for v0.13.1-pre.1
  * gopls/internal/lsp/source: reinstate equalOrigin for references check
  * gopls/internal/lsp/source: fix incorrect 'origin' logic for named types
  * gopls/internal/lsp/source: fix renaming of type parameters
  * gopls/internal/lsp/source: refresh embeddirective analyzer docs
* Mon Jul 31 2023 jkowalczyk@suse.com
- Update to version 0.13.0:
  * gopls: update go.mod for v0.13.0-pre.3
  * gopls/internal/lsp/source: Add SuggestedFix for embeddirective Analyzer
  * gopls/internal/lsp/cache: keep analysis progress reports on one line
  * gopls: update go.mod and go.sum for v0.13.0-pre.2
  * gopls/internal/lsp/cache: fast-path for type-checking active packages
  * gopls/internal/lsp/cache: fix use of time.NewTimer instead of NewTicker
  * gopls: fix tests that depend on log sequencing
  * gopls: update go.mod and go.sum for v0.13.0
  * gopls/internal/lsp/debug: update debug version for v0.13.0
  * all: update codereview.cfg for gopls-release-branch.0.13
  * gopls/internal/lsp/cache: use correct metadata in resolveImportGraph
  * gopls/internal/lsp/cache: fix incorrect check for active package
  * gopls/internal/lsp/source: highlight deprecated symbols
  * gopls/internal/lsp: don't recompute diagnostics during code actions
  * gopls/internal/lsp/cache: memoize active packages after every operation
  * gopls/internal/regtest/bench: add benchmarks for codeactions
  * gopls/internal/lsp/cache: fix boundary cond in parseCache age eviction
  * gopls/internal/lsp/cache: purge Analysis.Results earlier
  * gopls/internal/lsp/cache: limit parallelism
  * gopls/internal/lsp/cache: move purgeFuncBodies into the parse cache
  * gopls/internal/lsp/cache: used time-based eviction in parseCache
  * gopls/internal/lsp/frob: document another restriction
  * go/types/objectpath: avoid sorting methods for gopls
  * gopls/internal/lsp/cache: UX improvements for analysis
  * gopls/internal/lsp/cache: better panic if metadata invariant is broken
  * gopls/internal/lsp/cache: frob: a fast encoder with gob-like powers
  * gopls/internal/lsp: don't awaitLoaded inside resolveImportGraph
  * gopls/internal/lsp: fix a latent bug in orphaned file reloading
  * gopls/internal/lsp/source/typerefs: optimize getPackageHandles
  * gopls/internal/lsp: only diagnose one package per file
  * gopls/protocol/generate: upgrade generating LSP stubs
  * gopls/internal/lsp/debug: display Analysis.Run times
  * gopls/internal: update LSP support
  * gopls/internal/lsp/source: fix spurious "unexpected var object" error
  * gopls/internal/regtest/bench: add a test simulating typing
  * gopls/internal/regtest/bench: add an 'oracle' benchmark repo
  * gopls/internal/regtest/bench: clean up profile flags
  * gopls/internal/regtest/workspace: fix TestQuickFix_AddGoWork for go1.21
  * gopls: commands to start/stop profiling, and a new benchmark metric
  * gopls/internal/lsp/source: put context first in extracted functions
  * gopls/internal/lsp/source/completion: avoid duplicates from variants
  * gopls/internal/lsp: make gopls.start_debugging open browser
  * gopls/internal/lsp/filecache: increase idle GC period to 6 hours
  * gopls/internal/lsp/source/completion: honor usePlaceholders
  * gopls/internal/lsp/source/completion: placeholders for type params
  * gopls/internal/regtest/marker: skip addgowork.txt
  * gopls/internal/lsp/source/xrefs: include refs to methods of generics
  * gopls/internal/lsp/source: ignore objectpath error in rename
  * gopls: remove dead code
  * gopls/internal/lsp/cache: plumb analysis URLs to client
  * gopls/doc/contributing.md: document error handling strategies
  * gopls/internal/lsp/source/typerefs: move test into _test.go
  * gopls/internal/lsp/filecache: reduce GC frequency
  * gopls/internal/lsp/cmd: list bug reports in 'gopls bug'
  * gopls/internal/lsp/cache: don't panic when import fails during analysis
  * gopls/internal/lsp/cache: don't record edges to invalid packages
  * gopls/internal/lsp/cache: remove ITVs from shared import graph
* Mon Jun 26 2023 jkowalczyk@suse.com
- Update to version 0.12.4:
  * gopls/internal/lsp/cache: don't panic when import fails during analysis
  * gopls: update go.mod for v0.12.4
  * gopls/internal/lsp/cache: don't record edges to invalid packages
* Thu Jun 22 2023 jkowalczyk@suse.com
- Update to version 0.12.3:
  * gopls: update go.mod for v0.12.3
  * gopls/internal/lsp/cache: fix nil panic in analysis toSourceDiagnostic
  * gopls/internal/lsp/debug: update hard-coded version for v0.12.3
  * gopls/internal/lsp/cache: add debugging assertion for golang/go#60904
  * gopls/internal/lsp/cache: guard against "unsafe" by package path, not ID
  * gopls/internal/lsp/cache: use types.Unsafe in analysisPackage
  * gopls/internal/lsp/work: don't crash when hovering over broken mod dir
  * gopls/internal/lsp/cache: reduce importing in analysis
  * gopls/internal/regtest: fix goimports on windows when using vendoring
  * gopls/internal/lsp/source/completion: ensuring completion completeness
  * gopls/internal/regtest/codelens: set GOWORK=off for go mod vendor
  * gopls/internal/lsp/cache: two minor simplifications
  * gopls/internal/lsp/filecache: reduce lifespan of os.FileInfos
  * gopls/internal/lsp: enable min/max builtin completion test
* Mon Jun  5 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Refactor tarball unpacked sources layout with gopls/ as subdir.
  This allows us to include the LICENSE file at the upstream
  monorepo repository root. The changes required for the subdir
  layout are perhaps excessive for including just one metadata
  file, but serves as a good exercise for packaging other utilities
  under Go x/tools monorepo.
  * Upstream uses monorepo x/tools/ with gopls/ and others in subdirs
  * Upstream monorepo shared tools/LICENSE file in repository root dir
  * Move param subdir gopls usage from tar_scm to go_modules
  * tar_scm param include gopls and LICENSE
  * tar_scm param drop extraneous param exclude .git
  * Creates gopls-0.12.2.tar.gz unpacked layout gopls-0.12.2/gopls/go.mod
  * New layout requires moving LICENSE and vendor/ to subdir in %%prep
  * New layout requires change to subdir in %%build
  * New layout requires use path to subdir in %%check, %%install, %%files
* Mon Jun  5 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Initial package version 0.12.2:
  * Upstream uses monorepo x/tools/ with gopls/ and others in subdirs
  * service tar_scm use params subdir and filename both set to gopls
  * service go_modules_scm do not use any params
  * Creates gopls-0.12.2.tar.gz unpacked layout gopls-0.12.2/go.mod
  * Upstream monorepo shared tools/LICENSE file is one level above
    where we package
